Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4058)

Unified Diff: chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellActivity.java

Issue 184993005: Rename ChromiumTestShell classes to ChromeShell. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase yet again Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellActivity.java
diff --git a/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellActivity.java b/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellActivity.java
similarity index 96%
rename from chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellActivity.java
rename to chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellActivity.java
index f82d707bcf6e99a0ed89f7fa81409aea337d7c2e..64ac18997b5a8fccdef12cae817002b379c85386 100644
--- a/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromiumTestShellActivity.java
+++ b/chrome/android/testshell/java/src/org/chromium/chrome/shell/ChromeShellActivity.java
@@ -40,8 +40,8 @@ import org.chromium.ui.base.WindowAndroid;
/**
* The {@link android.app.Activity} component of a basic test shell to test Chrome features.
*/
-public class ChromiumTestShellActivity extends Activity implements AppMenuPropertiesDelegate {
- private static final String TAG = "ChromiumTestShellActivity";
+public class ChromeShellActivity extends Activity implements AppMenuPropertiesDelegate {
+ private static final String TAG = "ChromeShellActivity";
private WindowAndroid mWindow;
private TabManager mTabManager;
@@ -55,7 +55,7 @@ public class ChromiumTestShellActivity extends Activity implements AppMenuProper
protected void onCreate(final Bundle savedInstanceState) {
super.onCreate(savedInstanceState);
- ChromiumTestShellApplication.initCommandLine();
+ ChromeShellApplication.initCommandLine();
waitForDebuggerIfNeeded();
DeviceUtils.addDeviceSpecificUserAgentSwitch(this);
@@ -69,7 +69,7 @@ public class ChromiumTestShellActivity extends Activity implements AppMenuProper
@Override
public void onFailure() {
- Toast.makeText(ChromiumTestShellActivity.this,
+ Toast.makeText(ChromeShellActivity.this,
R.string.browser_process_initialization_failed,
Toast.LENGTH_SHORT).show();
Log.e(TAG, "Chromium browser process initialization failed");
@@ -271,7 +271,7 @@ public class ChromiumTestShellActivity extends Activity implements AppMenuProper
MenuItem forwardMenuItem = menu.findItem(R.id.forward_menu_id);
forwardMenuItem.setEnabled(getActiveTab().canGoForward());
// ChromiumTestShell does not know about bookmarks yet
menu.findItem(R.id.bookmark_this_page_id).setEnabled(false);
MenuItem signinItem = menu.findItem(R.id.signin);
@@ -271,7 +271,7 @@ public class ChromiumTestShellActivity extends Activity implements AppMenuProper
MenuItem forwardMenuItem = menu.findItem(R.id.forward_menu_id);
forwardMenuItem.setEnabled(getActiveTab().canGoForward());
- // ChromiumTestShell does not know about bookmarks yet
+ // ChromeShell does not know about bookmarks yet
menu.findItem(R.id.bookmark_this_page_id).setEnabled(false);
MenuItem signinItem = menu.findItem(R.id.signin);

Powered by Google App Engine
This is Rietveld 408576698